package vulnerability

import (
	grypeDb "github.com/anchore/grype/grype/db/v3"
)

type Fix struct {
	Versions []string
	State    grypeDb.FixState
}
